Index: kernel/generic/src/synch/spinlock.c
===================================================================
--- kernel/generic/src/synch/spinlock.c	(revision 31d8e103d56f8142eb714a22e4d2cbd7e22e5b5a)
+++ kernel/generic/src/synch/spinlock.c	(revision f74bbaf20e8d8be55495c56affc5b17ef6ea2bf0)
@@ -84,5 +84,5 @@
 
 		/*
 		 * We need to be careful about printflock and fb_lock.
 		 * Both of them are used to report deadlocks via
 		 * printf() and fb_putchar().
@@ -94,11 +94,11 @@
 		 * slow VESA framebuffer interaction (especially when
 		 * run in a simulator) that caused problems with both
-		 * printflock and fb_lock.
+		 * printf_lock and fb_lock.
 		 *
 		 * Possible deadlocks on both printflock and fb_lock
 		 * are therefore not reported as they would cause an
 		 * infinite recursion.
 		 */
-		if (sl == &printflock)
+		if (sl == &printf_lock)
 			continue;
 #ifdef CONFIG_FB
@@ -84,5 +84,5 @@
 
 		/*
-		 * We need to be careful about printflock and fb_lock.
+		 * We need to be careful about printf_lock and fb_lock.
 		 * Both of them are used to report deadlocks via
 		 * printf() and fb_putchar().
@@ -94,11 +94,11 @@
 		 *
-		 * Possible deadlocks on both printflock and fb_lock
+		 * Possible deadlocks on both printf_lock and fb_lock
 		 * are therefore not reported as they would cause an
 		 * infinite recursion.
